# Opsdroid Home Assistant

[![Build Status](https://img.shields.io/travis/com/opsdroid/opsdroid-homeassistant?logo=travis)](https://travis-ci.com/opsdroid/opsdroid-homeassistant)
[![codecov](https://codecov.io/gh/opsdroid/opsdroid-homeassistant/branch/master/graph/badge.svg)](https://codecov.io/gh/opsdroid/opsdroid-homeassistant)
[![Read the Docs](https://img.shields.io/readthedocs/opsdroid-homeassistant)](https://home-assistant.opsdroid.dev/en/latest/)

A plugin for Opsdroid to enable Home Assistant automation.

For more information [see the documentation](https://home-assistant.opsdroid.dev).
